from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="RemoveCompanyFromExclusionListBodyExcludedCompanyDetails")



@_attrs_define
class RemoveCompanyFromExclusionListBodyExcludedCompanyDetails:
    """ Details of the companies to remove from the exclusion list

        Attributes:
            domains (Union[None, Unset, list[str]]): Domains of the companies to remove from the exclusion list
            linkedin_urls (Union[None, Unset, list[str]]): LinkedIn URLs of the companies to remove from the exclusion list
     """

    domains: Union[None, Unset, list[str]] = UNSET
    linkedin_urls: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        domains: Union[None, Unset, list[str]]
        if isinstance(self.domains, Unset):
            domains = UNSET
        elif isinstance(self.domains, list):
            domains = self.domains


        else:
            domains = self.domains

        linkedin_urls: Union[None, Unset, list[str]]
        if isinstance(self.linkedin_urls, Unset):
            linkedin_urls = UNSET
        elif isinstance(self.linkedin_urls, list):
            linkedin_urls = self.linkedin_urls


        else:
            linkedin_urls = self.linkedin_urls


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if domains is not UNSET:
            field_dict["domains"] = domains
        if linkedin_urls is not UNSET:
            field_dict["linkedinUrls"] = linkedin_urls

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_domains(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                domains_type_0 = cast(list[str], data)

                return domains_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        domains = _parse_domains(d.pop("domains", UNSET))


        def _parse_linkedin_urls(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                linkedin_urls_type_0 = cast(list[str], data)

                return linkedin_urls_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        linkedin_urls = _parse_linkedin_urls(d.pop("linkedinUrls", UNSET))


        remove_company_from_exclusion_list_body_excluded_company_details = cls(
            domains=domains,
            linkedin_urls=linkedin_urls,
        )


        remove_company_from_exclusion_list_body_excluded_company_details.additional_properties = d
        return remove_company_from_exclusion_list_body_excluded_company_details

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetOrgCreditsResponse200OutputCreditsPerOperationType0StandardizeCompanySlugLevelsItem")



@_attrs_define
class GetOrgCreditsResponse200OutputCreditsPerOperationType0StandardizeCompanySlugLevelsItem:
    """ 
        Attributes:
            centi_credit_cost (float):
            limit (Union[None, Unset, float]):
     """

    centi_credit_cost: float
    limit: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        centi_credit_cost = self.centi_credit_cost

        limit: Union[None, Unset, float]
        if isinstance(self.limit, Unset):
            limit = UNSET
        else:
            limit = self.limit


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "centiCreditCost": centi_credit_cost,
        })
        if limit is not UNSET:
            field_dict["limit"] = limit

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        centi_credit_cost = d.pop("centiCreditCost")

        def _parse_limit(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        limit = _parse_limit(d.pop("limit", UNSET))


        get_org_credits_response_200_output_credits_per_operation_type_0_standardize_company_slug_levels_item = cls(
            centi_credit_cost=centi_credit_cost,
            limit=limit,
        )


        get_org_credits_response_200_output_credits_per_operation_type_0_standardize_company_slug_levels_item.additional_properties = d
        return get_org_credits_response_200_output_credits_per_operation_type_0_standardize_company_slug_levels_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCompanySearchResponse200OutputDataItemFullFundingRoundsType0ItemInvestorsType0Item")



@_attrs_define
class TextToCompanySearchResponse200OutputDataItemFullFundingRoundsType0ItemInvestorsType0Item:
    """ 
        Attributes:
            is_lead (Union[None, Unset, bool]):
            investor_name (Union[None, Unset, str]):
            investor_type (Union[None, Unset, str]):
            investor_domain (Union[None, Unset, str]):
            investor_categories (Union[None, Unset, list[str]]):
            investor_linkedin_url (Union[None, Unset, str]):
            investor_linkedin_org_id (Union[None, Unset, str]):
     """

    is_lead: Union[None, Unset, bool] = UNSET
    investor_name: Union[None, Unset, str] = UNSET
    investor_type: Union[None, Unset, str] = UNSET
    investor_domain: Union[None, Unset, str] = UNSET
    investor_categories: Union[None, Unset, list[str]] = UNSET
    investor_linkedin_url: Union[None, Unset, str] = UNSET
    investor_linkedin_org_id: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        is_lead: Union[None, Unset, bool]
        if isinstance(self.is_lead, Unset):
            is_lead = UNSET
        else:
            is_lead = self.is_lead

        investor_name: Union[None, Unset, str]
        if isinstance(self.investor_name, Unset):
            investor_name = UNSET
        else:
            investor_name = self.investor_name

        investor_type: Union[None, Unset, str]
        if isinstance(self.investor_type, Unset):
            investor_type = UNSET
        else:
            investor_type = self.investor_type

        investor_domain: Union[None, Unset, str]
        if isinstance(self.investor_domain, Unset):
            investor_domain = UNSET
        else:
            investor_domain = self.investor_domain

        investor_categories: Union[None, Unset, list[str]]
        if isinstance(self.investor_categories, Unset):
            investor_categories = UNSET
        elif isinstance(self.investor_categories, list):
            investor_categories = self.investor_categories


        else:
            investor_categories = self.investor_categories

        investor_linkedin_url: Union[None, Unset, str]
        if isinstance(self.investor_linkedin_url, Unset):
            investor_linkedin_url = UNSET
        else:
            investor_linkedin_url = self.investor_linkedin_url

        investor_linkedin_org_id: Union[None, Unset, str]
        if isinstance(self.investor_linkedin_org_id, Unset):
            investor_linkedin_org_id = UNSET
        else:
            investor_linkedin_org_id = self.investor_linkedin_org_id


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if is_lead is not UNSET:
            field_dict["is_lead"] = is_lead
        if investor_name is not UNSET:
            field_dict["investor_name"] = investor_name
        if investor_type is not UNSET:
            field_dict["investor_type"] = investor_type
        if investor_domain is not UNSET:
            field_dict["investor_domain"] = investor_domain
        if investor_categories is not UNSET:
            field_dict["investor_categories"] = investor_categories
        if investor_linkedin_url is not UNSET:
            field_dict["investor_linkedin_url"] = investor_linkedin_url
        if investor_linkedin_org_id is not UNSET:
            field_dict["investor_linkedin_org_id"] = investor_linkedin_org_id

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_is_lead(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_lead = _parse_is_lead(d.pop("is_lead", UNSET))


        def _parse_investor_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_name = _parse_investor_name(d.pop("investor_name", UNSET))


        def _parse_investor_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_type = _parse_investor_type(d.pop("investor_type", UNSET))


        def _parse_investor_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_domain = _parse_investor_domain(d.pop("investor_domain", UNSET))


        def _parse_investor_categories(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                investor_categories_type_0 = cast(list[str], data)

                return investor_categories_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        investor_categories = _parse_investor_categories(d.pop("investor_categories", UNSET))


        def _parse_investor_linkedin_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_linkedin_url = _parse_investor_linkedin_url(d.pop("investor_linkedin_url", UNSET))


        def _parse_investor_linkedin_org_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_linkedin_org_id = _parse_investor_linkedin_org_id(d.pop("investor_linkedin_org_id", UNSET))


        text_to_company_search_response_200_output_data_item_full_funding_rounds_type_0_item_investors_type_0_item = cls(
            is_lead=is_lead,
            investor_name=investor_name,
            investor_type=investor_type,
            investor_domain=investor_domain,
            investor_categories=investor_categories,
            investor_linkedin_url=investor_linkedin_url,
            investor_linkedin_org_id=investor_linkedin_org_id,
        )


        text_to_company_search_response_200_output_data_item_full_funding_rounds_type_0_item_investors_type_0_item.additional_properties = d
        return text_to_company_search_response_200_output_data_item_full_funding_rounds_type_0_item_investors_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetSavedSearchRunProfilesResponse200OutputProfilesItemProfileEducationType0Item")



@_attrs_define
class GetSavedSearchRunProfilesResponse200OutputProfilesItemProfileEducationType0Item:
    """ 
        Attributes:
            school_id (Union[None, Unset, str]):
            school_name (Union[None, Unset, str]):
            field_of_study_id (Union[None, Unset, str]):
            field_of_study_name (Union[None, Unset, str]):
            degree (Union[None, Unset, str]):
            grade (Union[None, Unset, str]):
            start_date (Union[None, Unset, str]):
            end_date (Union[None, Unset, str]):
            activities (Union[None, Unset, str]):
            notes (Union[None, Unset, str]):
     """

    school_id: Union[None, Unset, str] = UNSET
    school_name: Union[None, Unset, str] = UNSET
    field_of_study_id: Union[None, Unset, str] = UNSET
    field_of_study_name: Union[None, Unset, str] = UNSET
    degree: Union[None, Unset, str] = UNSET
    grade: Union[None, Unset, str] = UNSET
    start_date: Union[None, Unset, str] = UNSET
    end_date: Union[None, Unset, str] = UNSET
    activities: Union[None, Unset, str] = UNSET
    notes: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        school_id: Union[None, Unset, str]
        if isinstance(self.school_id, Unset):
            school_id = UNSET
        else:
            school_id = self.school_id

        school_name: Union[None, Unset, str]
        if isinstance(self.school_name, Unset):
            school_name = UNSET
        else:
            school_name = self.school_name

        field_of_study_id: Union[None, Unset, str]
        if isinstance(self.field_of_study_id, Unset):
            field_of_study_id = UNSET
        else:
            field_of_study_id = self.field_of_study_id

        field_of_study_name: Union[None, Unset, str]
        if isinstance(self.field_of_study_name, Unset):
            field_of_study_name = UNSET
        else:
            field_of_study_name = self.field_of_study_name

        degree: Union[None, Unset, str]
        if isinstance(self.degree, Unset):
            degree = UNSET
        else:
            degree = self.degree

        grade: Union[None, Unset, str]
        if isinstance(self.grade, Unset):
            grade = UNSET
        else:
            grade = self.grade

        start_date: Union[None, Unset, str]
        if isinstance(self.start_date, Unset):
            start_date = UNSET
        else:
            start_date = self.start_date

        end_date: Union[None, Unset, str]
        if isinstance(self.end_date, Unset):
            end_date = UNSET
        else:
            end_date = self.end_date

        activities: Union[None, Unset, str]
        if isinstance(self.activities, Unset):
            activities = UNSET
        else:
            activities = self.activities

        notes: Union[None, Unset, str]
        if isinstance(self.notes, Unset):
            notes = UNSET
        else:
            notes = self.notes


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if school_id is not UNSET:
            field_dict["school_id"] = school_id
        if school_name is not UNSET:
            field_dict["school_name"] = school_name
        if field_of_study_id is not UNSET:
            field_dict["field_of_study_id"] = field_of_study_id
        if field_of_study_name is not UNSET:
            field_dict["field_of_study_name"] = field_of_study_name
        if degree is not UNSET:
            field_dict["degree"] = degree
        if grade is not UNSET:
            field_dict["grade"] = grade
        if start_date is not UNSET:
            field_dict["start_date"] = start_date
        if end_date is not UNSET:
            field_dict["end_date"] = end_date
        if activities is not UNSET:
            field_dict["activities"] = activities
        if notes is not UNSET:
            field_dict["notes"] = notes

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_school_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        school_id = _parse_school_id(d.pop("school_id", UNSET))


        def _parse_school_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        school_name = _parse_school_name(d.pop("school_name", UNSET))


        def _parse_field_of_study_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        field_of_study_id = _parse_field_of_study_id(d.pop("field_of_study_id", UNSET))


        def _parse_field_of_study_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        field_of_study_name = _parse_field_of_study_name(d.pop("field_of_study_name", UNSET))


        def _parse_degree(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        degree = _parse_degree(d.pop("degree", UNSET))


        def _parse_grade(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        grade = _parse_grade(d.pop("grade", UNSET))


        def _parse_start_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        start_date = _parse_start_date(d.pop("start_date", UNSET))


        def _parse_end_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        end_date = _parse_end_date(d.pop("end_date", UNSET))


        def _parse_activities(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        activities = _parse_activities(d.pop("activities", UNSET))


        def _parse_notes(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        notes = _parse_notes(d.pop("notes", UNSET))


        get_saved_search_run_profiles_response_200_output_profiles_item_profile_education_type_0_item = cls(
            school_id=school_id,
            school_name=school_name,
            field_of_study_id=field_of_study_id,
            field_of_study_name=field_of_study_name,
            degree=degree,
            grade=grade,
            start_date=start_date,
            end_date=end_date,
            activities=activities,
            notes=notes,
        )


        get_saved_search_run_profiles_response_200_output_profiles_item_profile_education_type_0_item.additional_properties = d
        return get_saved_search_run_profiles_response_200_output_profiles_item_profile_education_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CombinedSearchBodyProfileParamsPastJobTextType0CriteriaItemRule(str, Enum):
    EXCLUDES = "excludes"
    INCLUDES = "includes"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investor_search_response_200_output_investors_item_investments_by_stage_type_0_item_stage_type_1 import InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1
from ..models.investor_search_response_200_output_investors_item_investments_by_stage_type_0_item_stage_type_2_type_1 import InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1
from ..models.investor_search_response_200_output_investors_item_investments_by_stage_type_0_item_stage_type_3_type_1 import InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0Item")



@_attrs_define
class InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0Item:
    """ 
        Attributes:
            total_count (int): Total investments at this stage
            lead_count (int): Lead investments at this stage
            lead_rate (float): Lead rate at this stage (0.0 - 1.0)
            share_of_portfolio (float): Share of total investments accounted for by this stage (0.0 - 1.0)
            stage (Union[InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1,
                InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1,
                InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1, None, Unset]): Funding
                stage (e.g., seed, series_a)
            last_investment_date (Union[None, Unset, str]): Date of most recent investment at this stage
     """

    total_count: int
    lead_count: int
    lead_rate: float
    share_of_portfolio: float
    stage: Union[InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1, None, Unset] = UNSET
    last_investment_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        total_count = self.total_count

        lead_count = self.lead_count

        lead_rate = self.lead_rate

        share_of_portfolio = self.share_of_portfolio

        stage: Union[None, Unset, str]
        if isinstance(self.stage, Unset):
            stage = UNSET
        elif isinstance(self.stage, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1):
            stage = self.stage.value
        elif isinstance(self.stage, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1):
            stage = self.stage.value
        elif isinstance(self.stage, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1):
            stage = self.stage.value
        else:
            stage = self.stage

        last_investment_date: Union[None, Unset, str]
        if isinstance(self.last_investment_date, Unset):
            last_investment_date = UNSET
        else:
            last_investment_date = self.last_investment_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "totalCount": total_count,
            "leadCount": lead_count,
            "leadRate": lead_rate,
            "shareOfPortfolio": share_of_portfolio,
        })
        if stage is not UNSET:
            field_dict["stage"] = stage
        if last_investment_date is not UNSET:
            field_dict["lastInvestmentDate"] = last_investment_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        total_count = d.pop("totalCount")

        lead_count = d.pop("leadCount")

        lead_rate = d.pop("leadRate")

        share_of_portfolio = d.pop("shareOfPortfolio")

        def _parse_stage(data: object) -> Union[InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                stage_type_1 = InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1(data)



                return stage_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                stage_type_2_type_1 = InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1(data)



                return stage_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                stage_type_3_type_1 = InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1(data)



                return stage_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType2Type1, InvestorSearchResponse200OutputInvestorsItemInvestmentsByStageType0ItemStageType3Type1, None, Unset], data)

        stage = _parse_stage(d.pop("stage", UNSET))


        def _parse_last_investment_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_investment_date = _parse_last_investment_date(d.pop("lastInvestmentDate", UNSET))


        investor_search_response_200_output_investors_item_investments_by_stage_type_0_item = cls(
            total_count=total_count,
            lead_count=lead_count,
            lead_rate=lead_rate,
            share_of_portfolio=share_of_portfolio,
            stage=stage,
            last_investment_date=last_investment_date,
        )


        investor_search_response_200_output_investors_item_investments_by_stage_type_0_item.additional_properties = d
        return investor_search_response_200_output_investors_item_investments_by_stage_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.people_search_body_search_params_stealth_v2_type_1_left_stealth_at_type_1_window_type_0_method import PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Method
from ..models.people_search_body_search_params_stealth_v2_type_1_left_stealth_at_type_1_window_type_0_period import PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Period






T = TypeVar("T", bound="PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0")



@_attrs_define
class PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0:
    """ 
        Attributes:
            method (PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Method):
            period (PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Period):
            quantity (float):
     """

    method: PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Method
    period: PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Period
    quantity: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        method = self.method.value

        period = self.period.value

        quantity = self.quantity


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "method": method,
            "period": period,
            "quantity": quantity,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        method = PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Method(d.pop("method"))




        period = PeopleSearchBodySearchParamsStealthV2Type1LeftStealthAtType1WindowType0Period(d.pop("period"))




        quantity = d.pop("quantity")

        people_search_body_search_params_stealth_v2_type_1_left_stealth_at_type_1_window_type_0 = cls(
            method=method,
            period=period,
            quantity=quantity,
        )


        people_search_body_search_params_stealth_v2_type_1_left_stealth_at_type_1_window_type_0.additional_properties = d
        return people_search_body_search_params_stealth_v2_type_1_left_stealth_at_type_1_window_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item import GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem





T = TypeVar("T", bound="GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0")



@_attrs_define
class GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0:
    """ 
        Attributes:
            num_offices_matched (float):
            matched_offices (list['GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0Ma
                tchedOfficesItem']):
     """

    num_offices_matched: float
    matched_offices: list['GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item import GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem
        num_offices_matched = self.num_offices_matched

        matched_offices = []
        for matched_offices_item_data in self.matched_offices:
            matched_offices_item = matched_offices_item_data.to_dict()
            matched_offices.append(matched_offices_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "num_offices_matched": num_offices_matched,
            "matched_offices": matched_offices,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item import GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem
        d = dict(src_dict)
        num_offices_matched = d.pop("num_offices_matched")

        matched_offices = []
        _matched_offices = d.pop("matched_offices")
        for matched_offices_item_data in (_matched_offices):
            matched_offices_item = GetCurrentCompaniesInSavedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem.from_dict(matched_offices_item_data)



            matched_offices.append(matched_offices_item)


        get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0 = cls(
            num_offices_matched=num_offices_matched,
            matched_offices=matched_offices,
        )


        get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0.additional_properties = d
        return get_current_companies_in_saved_search_response_200_output_companies_item_num_matching_locations_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item:
    """ 
        Attributes:
            id (Union[None, Unset, str]):
            title (Union[None, Unset, str]):
            date_published (Union[None, Unset, str]):
     """

    id: Union[None, Unset, str] = UNSET
    title: Union[None, Unset, str] = UNSET
    date_published: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        id: Union[None, Unset, str]
        if isinstance(self.id, Unset):
            id = UNSET
        else:
            id = self.id

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        date_published: Union[None, Unset, str]
        if isinstance(self.date_published, Unset):
            date_published = UNSET
        else:
            date_published = self.date_published


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if id is not UNSET:
            field_dict["id"] = id
        if title is not UNSET:
            field_dict["title"] = title
        if date_published is not UNSET:
            field_dict["date_published"] = date_published

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        id = _parse_id(d.pop("id", UNSET))


        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))


        def _parse_date_published(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        date_published = _parse_date_published(d.pop("date_published", UNSET))


        text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item = cls(
            id=id,
            title=title,
            date_published=date_published,
        )


        text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item.additional_properties = d
        return text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_functions_type_1 import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1
from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_functions_type_2_type_1 import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1
from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_functions_type_3_type_1 import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_changes_type_0_item import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item





T = TypeVar("T", bound="SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0Item")



@_attrs_define
class SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0Item:
    """ 
        Attributes:
            functions (Union[None, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1,
                SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1,
                SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1, Unset]):
            current_count (Union[None, Unset, float]):
            changes (Union[None, Unset,
                list['SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item']]):
     """

    functions: Union[None, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1, Unset] = UNSET
    current_count: Union[None, Unset, float] = UNSET
    changes: Union[None, Unset, list['SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item']] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_changes_type_0_item import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item
        functions: Union[None, Unset, str]
        if isinstance(self.functions, Unset):
            functions = UNSET
        elif isinstance(self.functions, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1):
            functions = self.functions.value
        elif isinstance(self.functions, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1):
            functions = self.functions.value
        elif isinstance(self.functions, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1):
            functions = self.functions.value
        else:
            functions = self.functions

        current_count: Union[None, Unset, float]
        if isinstance(self.current_count, Unset):
            current_count = UNSET
        else:
            current_count = self.current_count

        changes: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.changes, Unset):
            changes = UNSET
        elif isinstance(self.changes, list):
            changes = []
            for changes_type_0_item_data in self.changes:
                changes_type_0_item = changes_type_0_item_data.to_dict()
                changes.append(changes_type_0_item)


        else:
            changes = self.changes


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if functions is not UNSET:
            field_dict["functions"] = functions
        if current_count is not UNSET:
            field_dict["current_count"] = current_count
        if changes is not UNSET:
            field_dict["changes"] = changes

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item_changes_type_0_item import SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item
        d = dict(src_dict)
        def _parse_functions(data: object) -> Union[None, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                functions_type_1 = SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1(data)



                return functions_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                functions_type_2_type_1 = SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1(data)



                return functions_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                functions_type_3_type_1 = SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1(data)



                return functions_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType2Type1, SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemFunctionsType3Type1, Unset], data)

        functions = _parse_functions(d.pop("functions", UNSET))


        def _parse_current_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        current_count = _parse_current_count(d.pop("current_count", UNSET))


        def _parse_changes(data: object) -> Union[None, Unset, list['SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                changes_type_0 = []
                _changes_type_0 = data
                for changes_type_0_item_data in (_changes_type_0):
                    changes_type_0_item = SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item.from_dict(changes_type_0_item_data)



                    changes_type_0.append(changes_type_0_item)

                return changes_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['SyncCombinedSearchResponse200OutputCompaniesItemEmployeeTrendsType0ItemChangesType0Item']], data)

        changes = _parse_changes(d.pop("changes", UNSET))


        sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item = cls(
            functions=functions,
            current_count=current_count,
            changes=changes,
        )


        sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item.additional_properties = d
        return sync_combined_search_response_200_output_companies_item_employee_trends_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type(str, Enum):
    STATIC_GROUPS = "static-groups"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2_type import CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2Type
from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2_location_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2")



@_attrs_define
class CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2:
    """ 
        Attributes:
            type_ (CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2Type):
            location ('CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2Loc
                ationType0'):
     """

    type_: CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2Type
    location: 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2_location_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0
        type_ = self.type_.value

        location: dict[str, Any]
        if isinstance(self.location, CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0):
            location = self.location.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "location": location,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2_location_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0
        d = dict(src_dict)
        type_ = CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2Type(d.pop("type"))




        def _parse_location(data: object) -> 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0':
            if not isinstance(data, dict):
                raise TypeError()
            location_type_0 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0.from_dict(data)



            return location_type_0

        location = _parse_location(d.pop("location"))


        create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2 = cls(
            type_=type_,
            location=location,
        )


        create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2.additional_properties = d
        return create_saved_search_body_search_params_type_1_company_search_params_office_locations_v2_type_0_all_of_type_0_item_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanySearchBodySearchParamsOfficeLocationsV2Type0AllOfType0ItemType1Type(str, Enum):
    COUNTRY_OR_REGION = "country-or-region"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item_investors_type_0_item import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item





T = TypeVar("T", bound="GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0Item")



@_attrs_define
class GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0Item:
    """ 
        Attributes:
            investors (Union[None, Unset, list['GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRo
                undsType0ItemInvestorsType0Item']]):
            round_city (Union[None, Unset, str]):
            round_date (Union[None, Unset, str]):
            round_type (Union[None, Unset, str]):
            round_state (Union[None, Unset, str]):
            investor_count (Union[None, Unset, float]):
            round_raised_usd (Union[None, Unset, float]):
            round_country_code (Union[None, Unset, str]):
            round_valuation_usd (Union[None, Unset, float]):
     """

    investors: Union[None, Unset, list['GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item']] = UNSET
    round_city: Union[None, Unset, str] = UNSET
    round_date: Union[None, Unset, str] = UNSET
    round_type: Union[None, Unset, str] = UNSET
    round_state: Union[None, Unset, str] = UNSET
    investor_count: Union[None, Unset, float] = UNSET
    round_raised_usd: Union[None, Unset, float] = UNSET
    round_country_code: Union[None, Unset, str] = UNSET
    round_valuation_usd: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item_investors_type_0_item import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item
        investors: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.investors, Unset):
            investors = UNSET
        elif isinstance(self.investors, list):
            investors = []
            for investors_type_0_item_data in self.investors:
                investors_type_0_item = investors_type_0_item_data.to_dict()
                investors.append(investors_type_0_item)


        else:
            investors = self.investors

        round_city: Union[None, Unset, str]
        if isinstance(self.round_city, Unset):
            round_city = UNSET
        else:
            round_city = self.round_city

        round_date: Union[None, Unset, str]
        if isinstance(self.round_date, Unset):
            round_date = UNSET
        else:
            round_date = self.round_date

        round_type: Union[None, Unset, str]
        if isinstance(self.round_type, Unset):
            round_type = UNSET
        else:
            round_type = self.round_type

        round_state: Union[None, Unset, str]
        if isinstance(self.round_state, Unset):
            round_state = UNSET
        else:
            round_state = self.round_state

        investor_count: Union[None, Unset, float]
        if isinstance(self.investor_count, Unset):
            investor_count = UNSET
        else:
            investor_count = self.investor_count

        round_raised_usd: Union[None, Unset, float]
        if isinstance(self.round_raised_usd, Unset):
            round_raised_usd = UNSET
        else:
            round_raised_usd = self.round_raised_usd

        round_country_code: Union[None, Unset, str]
        if isinstance(self.round_country_code, Unset):
            round_country_code = UNSET
        else:
            round_country_code = self.round_country_code

        round_valuation_usd: Union[None, Unset, float]
        if isinstance(self.round_valuation_usd, Unset):
            round_valuation_usd = UNSET
        else:
            round_valuation_usd = self.round_valuation_usd


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if investors is not UNSET:
            field_dict["investors"] = investors
        if round_city is not UNSET:
            field_dict["round_city"] = round_city
        if round_date is not UNSET:
            field_dict["round_date"] = round_date
        if round_type is not UNSET:
            field_dict["round_type"] = round_type
        if round_state is not UNSET:
            field_dict["round_state"] = round_state
        if investor_count is not UNSET:
            field_dict["investor_count"] = investor_count
        if round_raised_usd is not UNSET:
            field_dict["round_raised_usd"] = round_raised_usd
        if round_country_code is not UNSET:
            field_dict["round_country_code"] = round_country_code
        if round_valuation_usd is not UNSET:
            field_dict["round_valuation_usd"] = round_valuation_usd

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item_investors_type_0_item import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item
        d = dict(src_dict)
        def _parse_investors(data: object) -> Union[None, Unset, list['GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                investors_type_0 = []
                _investors_type_0 = data
                for investors_type_0_item_data in (_investors_type_0):
                    investors_type_0_item = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item.from_dict(investors_type_0_item_data)



                    investors_type_0.append(investors_type_0_item)

                return investors_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyFullFundingRoundsType0ItemInvestorsType0Item']], data)

        investors = _parse_investors(d.pop("investors", UNSET))


        def _parse_round_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_city = _parse_round_city(d.pop("round_city", UNSET))


        def _parse_round_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_date = _parse_round_date(d.pop("round_date", UNSET))


        def _parse_round_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_type = _parse_round_type(d.pop("round_type", UNSET))


        def _parse_round_state(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_state = _parse_round_state(d.pop("round_state", UNSET))


        def _parse_investor_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        investor_count = _parse_investor_count(d.pop("investor_count", UNSET))


        def _parse_round_raised_usd(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        round_raised_usd = _parse_round_raised_usd(d.pop("round_raised_usd", UNSET))


        def _parse_round_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_country_code = _parse_round_country_code(d.pop("round_country_code", UNSET))


        def _parse_round_valuation_usd(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        round_valuation_usd = _parse_round_valuation_usd(d.pop("round_valuation_usd", UNSET))


        get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item = cls(
            investors=investors,
            round_city=round_city,
            round_date=round_date,
            round_type=round_type,
            round_state=round_state,
            investor_count=investor_count,
            round_raised_usd=round_raised_usd,
            round_country_code=round_country_code,
            round_valuation_usd=round_valuation_usd,
        )


        get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item.additional_properties = d
        return get_saved_search_run_companies_response_200_output_companies_item_company_full_funding_rounds_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetAcceleratorsResponse200OutputItemYearsType0Item")



@_attrs_define
class GetAcceleratorsResponse200OutputItemYearsType0Item:
    """ 
        Attributes:
            year (int): The year the companies participated in the accelerator
            num_companies (int): Number of companies in this year for this accelerator
     """

    year: int
    num_companies: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        year = self.year

        num_companies = self.num_companies


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "year": year,
            "numCompanies": num_companies,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        year = d.pop("year")

        num_companies = d.pop("numCompanies")

        get_accelerators_response_200_output_item_years_type_0_item = cls(
            year=year,
            num_companies=num_companies,
        )


        get_accelerators_response_200_output_item_years_type_0_item.additional_properties = d
        return get_accelerators_response_200_output_item_years_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_profile_search_response_200_output_search_params_time_zone_type_0_any_of_item_strategy_type_0_mode import TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0Mode






T = TypeVar("T", bound="TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0")



@_attrs_define
class TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0:
    """ 
        Attributes:
            mode (TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0Mode):
            midpoint_time_zone_name (str):
            max_minutes_westward (int):
            max_minutes_eastward (float):
            include_partial_year_matches (bool):
     """

    mode: TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0Mode
    midpoint_time_zone_name: str
    max_minutes_westward: int
    max_minutes_eastward: float
    include_partial_year_matches: bool
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        mode = self.mode.value

        midpoint_time_zone_name = self.midpoint_time_zone_name

        max_minutes_westward = self.max_minutes_westward

        max_minutes_eastward = self.max_minutes_eastward

        include_partial_year_matches = self.include_partial_year_matches


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "mode": mode,
            "midpointTimeZoneName": midpoint_time_zone_name,
            "maxMinutesWestward": max_minutes_westward,
            "maxMinutesEastward": max_minutes_eastward,
            "includePartialYearMatches": include_partial_year_matches,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        mode = TextToProfileSearchResponse200OutputSearchParamsTimeZoneType0AnyOfItemStrategyType0Mode(d.pop("mode"))




        midpoint_time_zone_name = d.pop("midpointTimeZoneName")

        max_minutes_westward = d.pop("maxMinutesWestward")

        max_minutes_eastward = d.pop("maxMinutesEastward")

        include_partial_year_matches = d.pop("includePartialYearMatches")

        text_to_profile_search_response_200_output_search_params_time_zone_type_0_any_of_item_strategy_type_0 = cls(
            mode=mode,
            midpoint_time_zone_name=midpoint_time_zone_name,
            max_minutes_westward=max_minutes_westward,
            max_minutes_eastward=max_minutes_eastward,
            include_partial_year_matches=include_partial_year_matches,
        )


        text_to_profile_search_response_200_output_search_params_time_zone_type_0_any_of_item_strategy_type_0.additional_properties = d
        return text_to_profile_search_response_200_output_search_params_time_zone_type_0_any_of_item_strategy_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_naics_codes_response_200_output_naics_codes_item import GetNaicsCodesResponse200OutputNaicsCodesItem





T = TypeVar("T", bound="GetNaicsCodesResponse200Output")



@_attrs_define
class GetNaicsCodesResponse200Output:
    """ 
        Attributes:
            naics_codes (list['GetNaicsCodesResponse200OutputNaicsCodesItem']): List of all NAICS codes with their titles.
                This is the 2017 version of the NAICS codes.
     """

    naics_codes: list['GetNaicsCodesResponse200OutputNaicsCodesItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_naics_codes_response_200_output_naics_codes_item import GetNaicsCodesResponse200OutputNaicsCodesItem
        naics_codes = []
        for naics_codes_item_data in self.naics_codes:
            naics_codes_item = naics_codes_item_data.to_dict()
            naics_codes.append(naics_codes_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "naicsCodes": naics_codes,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_naics_codes_response_200_output_naics_codes_item import GetNaicsCodesResponse200OutputNaicsCodesItem
        d = dict(src_dict)
        naics_codes = []
        _naics_codes = d.pop("naicsCodes")
        for naics_codes_item_data in (_naics_codes):
            naics_codes_item = GetNaicsCodesResponse200OutputNaicsCodesItem.from_dict(naics_codes_item_data)



            naics_codes.append(naics_codes_item)


        get_naics_codes_response_200_output = cls(
            naics_codes=naics_codes,
        )


        get_naics_codes_response_200_output.additional_properties = d
        return get_naics_codes_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0Method(str, Enum):
    LASTN = "lastN"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_status import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_stealth_duration_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1")



@_attrs_define
class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1:
    """ 
        Attributes:
            status (CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status):
            left_stealth_at
                (Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0',
                'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1', None, Unset]):
            entered_stealth_at
                (Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0',
                'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1', None, Unset]):
            stealth_duration
                (Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0', None,
                Unset]):
     """

    status: CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status
    left_stealth_at: Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1', None, Unset] = UNSET
    entered_stealth_at: Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1', None, Unset] = UNSET
    stealth_duration: Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_stealth_duration_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1
        status = self.status.value

        left_stealth_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.left_stealth_at, Unset):
            left_stealth_at = UNSET
        elif isinstance(self.left_stealth_at, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0):
            left_stealth_at = self.left_stealth_at.to_dict()
        elif isinstance(self.left_stealth_at, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1):
            left_stealth_at = self.left_stealth_at.to_dict()
        else:
            left_stealth_at = self.left_stealth_at

        entered_stealth_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.entered_stealth_at, Unset):
            entered_stealth_at = UNSET
        elif isinstance(self.entered_stealth_at, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0):
            entered_stealth_at = self.entered_stealth_at.to_dict()
        elif isinstance(self.entered_stealth_at, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1):
            entered_stealth_at = self.entered_stealth_at.to_dict()
        else:
            entered_stealth_at = self.entered_stealth_at

        stealth_duration: Union[None, Unset, dict[str, Any]]
        if isinstance(self.stealth_duration, Unset):
            stealth_duration = UNSET
        elif isinstance(self.stealth_duration, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0):
            stealth_duration = self.stealth_duration.to_dict()
        else:
            stealth_duration = self.stealth_duration


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "status": status,
        })
        if left_stealth_at is not UNSET:
            field_dict["leftStealthAt"] = left_stealth_at
        if entered_stealth_at is not UNSET:
            field_dict["enteredStealthAt"] = entered_stealth_at
        if stealth_duration is not UNSET:
            field_dict["stealthDuration"] = stealth_duration

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_stealth_duration_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_left_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1_entered_stealth_at_type_1 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1
        d = dict(src_dict)
        status = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status(d.pop("status"))




        def _parse_left_stealth_at(data: object) -> Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                left_stealth_at_type_0 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0.from_dict(data)



                return left_stealth_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                left_stealth_at_type_1 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1.from_dict(data)



                return left_stealth_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1LeftStealthAtType1', None, Unset], data)

        left_stealth_at = _parse_left_stealth_at(d.pop("leftStealthAt", UNSET))


        def _parse_entered_stealth_at(data: object) -> Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                entered_stealth_at_type_0 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0.from_dict(data)



                return entered_stealth_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                entered_stealth_at_type_1 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1.from_dict(data)



                return entered_stealth_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType0', 'CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1EnteredStealthAtType1', None, Unset], data)

        entered_stealth_at = _parse_entered_stealth_at(d.pop("enteredStealthAt", UNSET))


        def _parse_stealth_duration(data: object) -> Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stealth_duration_type_0 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0.from_dict(data)



                return stealth_duration_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1StealthDurationType0', None, Unset], data)

        stealth_duration = _parse_stealth_duration(d.pop("stealthDuration", UNSET))


        create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1 = cls(
            status=status,
            left_stealth_at=left_stealth_at,
            entered_stealth_at=entered_stealth_at,
            stealth_duration=stealth_duration,
        )


        create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1.additional_properties = d
        return create_saved_search_body_search_params_type_2_profile_search_params_stealth_v2_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.get_current_profiles_in_saved_search_response_200_output_profiles_item import GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem





T = TypeVar("T", bound="GetCurrentProfilesInSavedSearchResponse200Output")



@_attrs_define
class GetCurrentProfilesInSavedSearchResponse200Output:
    """ 
        Attributes:
            profiles (list['GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem']): The profiles found for the
                saved search by movement type
            next_cursor (Union[None, Unset, str]): The next cursor
            last_run_completed_at (Union[None, Unset, str]): The date and time the last run completed
     """

    profiles: list['GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem']
    next_cursor: Union[None, Unset, str] = UNSET
    last_run_completed_at: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_current_profiles_in_saved_search_response_200_output_profiles_item import GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem
        profiles = []
        for profiles_item_data in self.profiles:
            profiles_item = profiles_item_data.to_dict()
            profiles.append(profiles_item)



        next_cursor: Union[None, Unset, str]
        if isinstance(self.next_cursor, Unset):
            next_cursor = UNSET
        else:
            next_cursor = self.next_cursor

        last_run_completed_at: Union[None, Unset, str]
        if isinstance(self.last_run_completed_at, Unset):
            last_run_completed_at = UNSET
        else:
            last_run_completed_at = self.last_run_completed_at


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "profiles": profiles,
        })
        if next_cursor is not UNSET:
            field_dict["nextCursor"] = next_cursor
        if last_run_completed_at is not UNSET:
            field_dict["lastRunCompletedAt"] = last_run_completed_at

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_current_profiles_in_saved_search_response_200_output_profiles_item import GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem
        d = dict(src_dict)
        profiles = []
        _profiles = d.pop("profiles")
        for profiles_item_data in (_profiles):
            profiles_item = GetCurrentProfilesInSavedSearchResponse200OutputProfilesItem.from_dict(profiles_item_data)



            profiles.append(profiles_item)


        def _parse_next_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        next_cursor = _parse_next_cursor(d.pop("nextCursor", UNSET))


        def _parse_last_run_completed_at(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_run_completed_at = _parse_last_run_completed_at(d.pop("lastRunCompletedAt", UNSET))


        get_current_profiles_in_saved_search_response_200_output = cls(
            profiles=profiles,
            next_cursor=next_cursor,
            last_run_completed_at=last_run_completed_at,
        )


        get_current_profiles_in_saved_search_response_200_output.additional_properties = d
        return get_current_profiles_in_saved_search_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class GetCurrentCompaniesInSavedSearchResponse200ChargeInfoType1Method(str, Enum):
    CHARGING_LATER = "charging-later"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CompanySearchBodySearchParamsJobPostingStatsType0AnyOfType0ItemType3EmploymentType(str, Enum):
    CONTRACT = "Contract"
    FULL_TIME = "Full-time"
    INTERNSHIP = "Internship"
    OTHER = "Other"
    PART_TIME = "Part-time"
    TEMPORARY = "Temporary"
    VOLUNTEER = "Volunteer"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class KitchenSinkCompanyResponse200OutputDataItemTagsType0Item(str, Enum):
    IS_GOVERNMENT = "is-government"
    IS_SCHOOL = "is-school"
    RAISED_FROM_TOP_VC = "raised-from-top-vc"
    VENTURE_BACKED_STARTUP = "venture-backed-startup"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="ProfileLiveEnrichResponse200ProfileFoundAndEnrichedProfileVolunteeringType0Item")



@_attrs_define
class ProfileLiveEnrichResponse200ProfileFoundAndEnrichedProfileVolunteeringType0Item:
    """ 
        Attributes:
            role (Union[None, Unset, str]):
            is_current (Union[None, Unset, bool]):
            cause (Union[None, Unset, str]):
            summary (Union[None, Unset, str]):
            linkedin_company_id (Union[None, Unset, str]):
            company_name (Union[None, Unset, str]):
            start_date (Union[None, Unset, str]):
            end_date (Union[None, Unset, str]):
     """

    role: Union[None, Unset, str] = UNSET
    is_current: Union[None, Unset, bool] = UNSET
    cause: Union[None, Unset, str] = UNSET
    summary: Union[None, Unset, str] = UNSET
    linkedin_company_id: Union[None, Unset, str] = UNSET
    company_name: Union[None, Unset, str] = UNSET
    start_date: Union[None, Unset, str] = UNSET
    end_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        role: Union[None, Unset, str]
        if isinstance(self.role, Unset):
            role = UNSET
        else:
            role = self.role

        is_current: Union[None, Unset, bool]
        if isinstance(self.is_current, Unset):
            is_current = UNSET
        else:
            is_current = self.is_current

        cause: Union[None, Unset, str]
        if isinstance(self.cause, Unset):
            cause = UNSET
        else:
            cause = self.cause

        summary: Union[None, Unset, str]
        if isinstance(self.summary, Unset):
            summary = UNSET
        else:
            summary = self.summary

        linkedin_company_id: Union[None, Unset, str]
        if isinstance(self.linkedin_company_id, Unset):
            linkedin_company_id = UNSET
        else:
            linkedin_company_id = self.linkedin_company_id

        company_name: Union[None, Unset, str]
        if isinstance(self.company_name, Unset):
            company_name = UNSET
        else:
            company_name = self.company_name

        start_date: Union[None, Unset, str]
        if isinstance(self.start_date, Unset):
            start_date = UNSET
        else:
            start_date = self.start_date

        end_date: Union[None, Unset, str]
        if isinstance(self.end_date, Unset):
            end_date = UNSET
        else:
            end_date = self.end_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if role is not UNSET:
            field_dict["role"] = role
        if is_current is not UNSET:
            field_dict["is_current"] = is_current
        if cause is not UNSET:
            field_dict["cause"] = cause
        if summary is not UNSET:
            field_dict["summary"] = summary
        if linkedin_company_id is not UNSET:
            field_dict["linkedin_company_id"] = linkedin_company_id
        if company_name is not UNSET:
            field_dict["company_name"] = company_name
        if start_date is not UNSET:
            field_dict["start_date"] = start_date
        if end_date is not UNSET:
            field_dict["end_date"] = end_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_role(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        role = _parse_role(d.pop("role", UNSET))


        def _parse_is_current(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_current = _parse_is_current(d.pop("is_current", UNSET))


        def _parse_cause(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cause = _parse_cause(d.pop("cause", UNSET))


        def _parse_summary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        summary = _parse_summary(d.pop("summary", UNSET))


        def _parse_linkedin_company_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_company_id = _parse_linkedin_company_id(d.pop("linkedin_company_id", UNSET))


        def _parse_company_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        company_name = _parse_company_name(d.pop("company_name", UNSET))


        def _parse_start_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        start_date = _parse_start_date(d.pop("start_date", UNSET))


        def _parse_end_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        end_date = _parse_end_date(d.pop("end_date", UNSET))


        profile_live_enrich_response_200_profile_found_and_enriched_profile_volunteering_type_0_item = cls(
            role=role,
            is_current=is_current,
            cause=cause,
            summary=summary,
            linkedin_company_id=linkedin_company_id,
            company_name=company_name,
            start_date=start_date,
            end_date=end_date,
        )


        profile_live_enrich_response_200_profile_found_and_enriched_profile_volunteering_type_0_item.additional_properties = d
        return profile_live_enrich_response_200_profile_found_and_enriched_profile_volunteering_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyProfileParamsEducationType0AllOfType0ItemStartedSchoolAtType1WindowType2Method(str, Enum):
    CALENDAR = "calendar"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.people_search_body_search_params import PeopleSearchBodySearchParams
  from ..models.people_search_body_current_companies_type_0_item import PeopleSearchBodyCurrentCompaniesType0Item





T = TypeVar("T", bound="PeopleSearchBody")



@_attrs_define
class PeopleSearchBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            search_params (Union[Unset, PeopleSearchBodySearchParams]): Search parameters for people search.
            page_size (Union[Unset, int]): The number of profiles to return, if you need to get more results, you can
                paginate. Default: 25.
            cursor (Union[None, Unset, str]): A pagination cursor returned from a previous search response. Use this to
                fetch the next page of results.
            current_companies (Union[None, Unset, list['PeopleSearchBodyCurrentCompaniesType0Item']]): Filter people by the
                companies they are currently working for. If you want to search over many companies, we suggest using the
                Combined Search API, which is optimized for this use case.
            prospect_exclusion_list_i_ds (Union[None, Unset, list[str]]): Filter out people which belong to the given
                prospect exclusion lists
            company_exclusion_list_i_ds (Union[None, Unset, list[str]]): Filter out people who work at companies which
                belong to the given company exclusion lists
     """

    api_key: str
    search_params: Union[Unset, 'PeopleSearchBodySearchParams'] = UNSET
    page_size: Union[Unset, int] = 25
    cursor: Union[None, Unset, str] = UNSET
    current_companies: Union[None, Unset, list['PeopleSearchBodyCurrentCompaniesType0Item']] = UNSET
    prospect_exclusion_list_i_ds: Union[None, Unset, list[str]] = UNSET
    company_exclusion_list_i_ds: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.people_search_body_search_params import PeopleSearchBodySearchParams
        from ..models.people_search_body_current_companies_type_0_item import PeopleSearchBodyCurrentCompaniesType0Item
        api_key = self.api_key

        search_params: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.search_params, Unset):
            search_params = self.search_params.to_dict()

        page_size = self.page_size

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor

        current_companies: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.current_companies, Unset):
            current_companies = UNSET
        elif isinstance(self.current_companies, list):
            current_companies = []
            for current_companies_type_0_item_data in self.current_companies:
                current_companies_type_0_item = current_companies_type_0_item_data.to_dict()
                current_companies.append(current_companies_type_0_item)


        else:
            current_companies = self.current_companies

        prospect_exclusion_list_i_ds: Union[None, Unset, list[str]]
        if isinstance(self.prospect_exclusion_list_i_ds, Unset):
            prospect_exclusion_list_i_ds = UNSET
        elif isinstance(self.prospect_exclusion_list_i_ds, list):
            prospect_exclusion_list_i_ds = self.prospect_exclusion_list_i_ds


        else:
            prospect_exclusion_list_i_ds = self.prospect_exclusion_list_i_ds

        company_exclusion_list_i_ds: Union[None, Unset, list[str]]
        if isinstance(self.company_exclusion_list_i_ds, Unset):
            company_exclusion_list_i_ds = UNSET
        elif isinstance(self.company_exclusion_list_i_ds, list):
            company_exclusion_list_i_ds = self.company_exclusion_list_i_ds


        else:
            company_exclusion_list_i_ds = self.company_exclusion_list_i_ds


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
        })
        if search_params is not UNSET:
            field_dict["searchParams"] = search_params
        if page_size is not UNSET:
            field_dict["pageSize"] = page_size
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if current_companies is not UNSET:
            field_dict["currentCompanies"] = current_companies
        if prospect_exclusion_list_i_ds is not UNSET:
            field_dict["prospectExclusionListIDs"] = prospect_exclusion_list_i_ds
        if company_exclusion_list_i_ds is not UNSET:
            field_dict["companyExclusionListIDs"] = company_exclusion_list_i_ds

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.people_search_body_search_params import PeopleSearchBodySearchParams
        from ..models.people_search_body_current_companies_type_0_item import PeopleSearchBodyCurrentCompaniesType0Item
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        _search_params = d.pop("searchParams", UNSET)
        search_params: Union[Unset, PeopleSearchBodySearchParams]
        if isinstance(_search_params,  Unset):
            search_params = UNSET
        else:
            search_params = PeopleSearchBodySearchParams.from_dict(_search_params)




        page_size = d.pop("pageSize", UNSET)

        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        def _parse_current_companies(data: object) -> Union[None, Unset, list['PeopleSearchBodyCurrentCompaniesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                current_companies_type_0 = []
                _current_companies_type_0 = data
                for current_companies_type_0_item_data in (_current_companies_type_0):
                    current_companies_type_0_item = PeopleSearchBodyCurrentCompaniesType0Item.from_dict(current_companies_type_0_item_data)



                    current_companies_type_0.append(current_companies_type_0_item)

                return current_companies_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['PeopleSearchBodyCurrentCompaniesType0Item']], data)

        current_companies = _parse_current_companies(d.pop("currentCompanies", UNSET))


        def _parse_prospect_exclusion_list_i_ds(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                prospect_exclusion_list_i_ds_type_0 = cast(list[str], data)

                return prospect_exclusion_list_i_ds_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        prospect_exclusion_list_i_ds = _parse_prospect_exclusion_list_i_ds(d.pop("prospectExclusionListIDs", UNSET))


        def _parse_company_exclusion_list_i_ds(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                company_exclusion_list_i_ds_type_0 = cast(list[str], data)

                return company_exclusion_list_i_ds_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        company_exclusion_list_i_ds = _parse_company_exclusion_list_i_ds(d.pop("companyExclusionListIDs", UNSET))


        people_search_body = cls(
            api_key=api_key,
            search_params=search_params,
            page_size=page_size,
            cursor=cursor,
            current_companies=current_companies,
            prospect_exclusion_list_i_ds=prospect_exclusion_list_i_ds,
            company_exclusion_list_i_ds=company_exclusion_list_i_ds,
        )


        people_search_body.additional_properties = d
        return people_search_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class GoogleMapsSearchBodyStrategyType2LargestCityTierIDType3Type1(str, Enum):
    LARGE = "large"
    MAJOR = "major"
    MEDIUM = "medium"
    MEGA = "mega"
    MINOR = "minor"
    SMALL = "small"
    TINY = "tiny"

    def __str__(self) -> str:
        return str(self.value)
